aerosoltools.aerosol2d.Aerosol2D.plot_total_conc — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.plot_total_conc

Aerosol2D.plot_total_conc(ax=None, mark_activities=False)

  Plot the total concentration over time.

  ## Parameters

  axmatplotlib.axes.Axes, optional

    An existing Matplotlib Axes object. If None, a new figure and axes are created.

  mark_activitiesbool or list of str, optional

    If True, highlights all activity periods except “All data”. If a list of activity names is provided, only those will be highlighted. If False (default), no activities are marked.

  ## Returns

  figmatplotlib.figure.Figure

    The Matplotlib figure object.

  axmatplotlib.axes.Axes

    The Matplotlib axes object with the plot.